@@ -3,13 +3,14 @@ autoreconf
 ./configure \
   $PKGCFG \
   $CROSSCFG \
-  --with-ptw32=/opt/mxe/usr/i686-pc-mingw32 \
+  --with-ptw32=$PREFIX/usr/i686-w64-mingw32.static \
   --enable-static \
   PTW32_LIBS="-lpthread -lpcreposix -lpcre -lregex" \
-  FLTK_CONFIG=$PREFIX/bin/i686-pc-mingw32-fltk-config
+  FLTK_CONFIG=$PREFIX/bin/i686-w64-mingw32.static-fltk-config
 
 make
-$PREFIX/bin/i686-pc-mingw32-strip src/flamp.exe
+
+$PREFIX/bin/i686-w64-mingw32.static-strip src/flamp.exe
 make nsisinst
 mv src/*setup*exe .
 
